@@ -1,11 +1,12 @@
 import logging
 import sys
 
-from django.apps import AppConfig
+from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 
-from gdaps.pluginmanager import PluginManager
 from gdaps import __version__
 from gdaps.api import PluginConfig
+from gdaps.pluginmanager import PluginManager
 
 logger = logging.getLogger(__name__)
 
@@ -41,10 +42,13 @@ class GdapsConfig(PluginConfig):
 
                     sys.exit(1)
 
+        if not settings.PROJECT_NAME:
+            raise ImproperlyConfigured('GDAPS needs a PROJECT_NAME settings variable.')
+
         # load all generic gdaps.plugins - they must be implementations of GDAPS Interfaces
         logger.info("Loading gdaps plugins...")
         for entry_point in pkg_resources.iter_entry_points(
-            group="gdaps.plugins", name=None
+                group="gdaps.plugins", name=None
         ):  # type: pkg_resources.EntryPoint
             # it is enough to have them instantiated, as they are remembered internally in their interface.
             entry_point.load()
