@@ -17,7 +17,7 @@ DEFAULTS = {
     "ADMIN": True,
     # the project's name. Mostly, it's the first part of ROOT_URLPATH, but it can differ.
     # It is used for template variables and file names in plugins. Must be a valid identifier.
-    "PROJECT_NAME": None,  # type: str
+    "PROJECT_TITLE": None,  # type: str
 }
 
 # List of settings that may be in string import notation.
