@@ -1,6 +1,6 @@
 from django.urls import path, include
 
-app_name = "gdaps.core"
+app_name = "gdaps"
 # automatically include Django-REST-Framework's URLs
 urlpatterns = []
 # FIXME: rest_framework namespace can't be chained?
