@@ -1,14 +1,13 @@
+import logging
 import os
 import string
-import logging
 
+from django.apps import apps
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.management.base import CommandError
 from nltk import PorterStemmer
 
-from django.apps import apps
-
 from gdaps.conf import gdaps_settings
 from gdaps.management.templates import TemplateCommand
 from gdaps.pluginmanager import PluginManager
@@ -126,6 +125,8 @@ class Command(TemplateCommand):
 
             options[key] = s
         camel_cased_name = "".join(x for x in name.title() if x != "_")
+        project_title = gdaps_settings.PROJECT_TITLE or settings.PROJECT_NAME.replace("_", " ").capitalize()
+
         self.context.update(
             {
                 **options,
@@ -133,10 +134,8 @@ class Command(TemplateCommand):
                 "camel_case_app_name": camel_cased_name,
                 "upper_cased_app_name": name.upper(),
                 "spaced_app_name": _snake_case_to_spaces(name),
-                "project_name": gdaps_settings.PROJECT_NAME,
-                "project_title": gdaps_settings.PROJECT_NAME.replace(
-                    "_", " "
-                ).capitalize(),
+                "project_name": settings.PROJECT_NAME,
+                "project_title": project_title,
                 "plugin_name": self.plugin_name,
                 "plugin_path": plugin_path,
                 "plugin_group": PluginManager.group,
