@@ -157,9 +157,8 @@ class PluginManager:
             dotted_name = f"{app.name}.{submodule}"
             try:
                 module = importlib.import_module(dotted_name)
-                logger.info(f" ✓ Successfully loaded submodule {dotted_name}")
                 modules.append(module)
-                logger.info(f" ✓ Loading plugin {dotted_name}")
+                logger.info(f" ✓ Successfully loaded plugin submodule {dotted_name}")
             except ImportError as e:
                 if mandatory:
                     raise PluginError(
@@ -213,7 +212,7 @@ class PluginManager:
         .. note:: This method needs Django's ORM to be running.
         """
 
-        from gdaps.core.models import GdapsPlugin
+        from gdaps.models import GdapsPlugin
 
         return GdapsPlugin.objects.exclude(
             name__in=[app.name for app in PluginManager.plugins()]
