@@ -1,7 +1,6 @@
 import os
 
 import django
-from django.core import management
 
 
 def pytest_configure(config):
@@ -15,6 +14,8 @@ def pytest_configure(config):
         },
         INSTALLED_APPS=["gdaps", "tests.plugins.plugin1"],
         PLUGIN1={"OVERRIDE": 20},
+        PROJECT_NAME="foo_bar",
+        GDAPS={"FRONTEND_ENGINE": "unknown"},
     )
 
     django.setup()
