@@ -2,8 +2,8 @@ import pytest
 
 from gdaps.api import InterfaceMeta
 from gdaps.conf import PluginSettings
-from .plugins.plugin1.conf import plugin1_settings, NAMESPACE, IMPORT_STRINGS
 from .plugins.plugin1.api.interfaces import IFirstInterface
+from .plugins.plugin1.conf import IMPORT_STRINGS, NAMESPACE, plugin1_settings
 
 
 def test_simple_default_value():
@@ -73,12 +73,6 @@ def test_notallowed_removed_setting_access():
         settings.REMOVED_SETTING
 
 
-def test_project_name_empty():
-    settings = PluginSettings(namespace="GDAPS")
-    assert settings.PROJECT_NAME is None
-
-
-def test_project_name():
-    defaults = {"PROJECT_NAME": "foo_bar"}
-    settings = PluginSettings(namespace="GDAPS", defaults=defaults,)
-    assert settings.PROJECT_NAME == "foo_bar"
+def test_gdaps_namespaced_integrated_setting():
+    gdaps_settings = PluginSettings(namespace="GDAPS", )
+    assert gdaps_settings.ADMIN == True
